@@ -56,6 +56,8 @@ static inline const char *ranap_domain_name(RANAP_CN_DomainIndicator_t domain)
 #define DEFAULT_PC_HNBGW ((23 << 3) + 5)
 #define DEFAULT_PC_MSC ((23 << 3) + 1)
 #define DEFAULT_PC_SGSN ((23 << 3) + 4)
+#define DEFAULT_ADDR_NAME_MSC "addr-dyn-msc-default"
+#define DEFAULT_ADDR_NAME_SGSN "addr-dyn-sgsn-default"
 
 /* 25.467 Section 7.1 */
 #define IUH_DEFAULT_SCTP_PORT	29169
@@ -86,9 +88,6 @@ struct hnbgw {
 		const char *iuh_local_ip;
 		/*! SCTP port for Iuh listening */
 		uint16_t iuh_local_port;
-		/*! The UDP port where we receive multiplexed CS user
-		 * plane traffic from HNBs */
-		uint16_t iuh_cs_mux_port;
 		struct osmo_plmn_id plmn;
 		uint16_t rnc_id;
 		bool hnbap_allow_tmsi;
