@@ -1,4 +1,4 @@
-/* hnb-gw specific code for HNBAP */
+/* hnb-gw specific code for HNBAP, 3GPP TS 25.469 */
 
 /* (C) 2015 by Harald Welte <laforge@gnumonks.org>
  * All Rights Reserved
@@ -33,6 +33,8 @@
 #include <osmocom/hnbap/hnbap_common.h>
 #include <osmocom/ranap/iu_helpers.h>
 
+#include <osmocom/hnbgw/hnb.h>
+#include <osmocom/hnbgw/hnb_persistent.h>
 #include <osmocom/hnbgw/hnbgw.h>
 #include <osmocom/hnbap/hnbap_ies_defs.h>
 
@@ -341,7 +343,7 @@ static int hnbgw_tx_ue_register_rej(struct hnb_context *hnb, HNBAP_UE_Identity_t
 	return hnbgw_hnbap_tx(hnb, msg);
 }
 
-static int hnbgw_tx_ue_register_acc_tmsi(struct hnb_context *hnb, HNBAP_UE_Identity_t *ue_id)
+static int hnbgw_tx_ue_register_acc_tmsi(struct hnb_context *hnb, HNBAP_UE_Identity_t *ue_id, uint32_t context_id)
 {
 	HNBAP_UERegisterAccept_t accept_out;
 	HNBAP_UERegisterAcceptIEs_t accept;
@@ -393,7 +395,7 @@ static int hnbgw_tx_ue_register_acc_tmsi(struct hnb_context *hnb, HNBAP_UE_Ident
 	tmsi = ntohl(tmsi);
 	LOGHNB(hnb, DHNBAP, LOGL_DEBUG, "HNBAP register with TMSI %x\n", tmsi);
 
-	asn1_u24_to_bitstring(&accept.context_ID, &ctx_id, get_next_ue_ctx_id());
+	asn1_u24_to_bitstring(&accept.context_ID, &ctx_id, context_id);
 
 	memset(&accept_out, 0, sizeof(accept_out));
 	rc = hnbap_encode_ueregisteraccepties(&accept_out, &accept);
@@ -471,7 +473,7 @@ static int hnbgw_rx_hnb_register_req(struct hnb_context *ctx, ANY_t *in)
 	struct hnb_context *hnb, *tmp;
 	HNBAP_HNBRegisterRequestIEs_t ies;
 	int rc;
-	struct osmo_fd *ofd = osmo_stream_srv_get_ofd(ctx->conn);
+	int fd = osmo_stream_srv_get_fd(ctx->conn);
 	char identity_str[256];
 	const char *cell_id_str;
 	struct timespec tp;
@@ -501,7 +503,7 @@ static int hnbgw_rx_hnb_register_req(struct hnb_context *ctx, ANY_t *in)
 	osmo_plmn_from_bcd(ies.plmNidentity.buf, &ctx->id.plmn);
 	cell_id_str = umts_cell_id_to_str(&ctx->id);
 
-	if (getpeername(ofd->fd, &cur_osa.u.sa, &len) < 0) {
+	if (getpeername(fd, &cur_osa.u.sa, &len) < 0) {
 		LOGHNB(ctx, DHNBAP, LOGL_ERROR, "HNB-REGISTER-REQ %s: rejecting due to getpeername() error: %s\n",
 		       cell_id_str, strerror(errno));
 		hnbap_free_hnbregisterrequesties(&ies);
@@ -533,10 +535,10 @@ static int hnbgw_rx_hnb_register_req(struct hnb_context *ctx, ANY_t *in)
 		if (hnb->hnb_registered && ctx != hnb && memcmp(&ctx->id, &hnb->id, sizeof(ctx->id)) == 0) {
 			/* If it's coming from the same remote IP addr+port, then it must be our internal
 			 * fault (bug), and we release the old context to keep going... */
-			struct osmo_fd *other_fd = osmo_stream_srv_get_ofd(hnb->conn);
+			int other_fd = osmo_stream_srv_get_fd(hnb->conn);
 			struct osmo_sockaddr other_osa = {};
 			socklen_t len = sizeof(other_osa);
-			if (getpeername(other_fd->fd, &other_osa.u.sa, &len) < 0) {
+			if (getpeername(other_fd, &other_osa.u.sa, &len) < 0) {
 				LOGHNB(ctx, DHNBAP, LOGL_ERROR, "BUG! Found old registered HNB with invalid socket, releasing it\n");
 				hnb_context_release(hnb);
 				continue;
@@ -616,7 +618,7 @@ static int hnbgw_rx_ue_register_req(struct hnb_context *ctx, ANY_t *in)
 	case HNBAP_UE_Identity_PR_tMSILAI:
 	case HNBAP_UE_Identity_PR_pTMSIRAI:
 		if (g_hnbgw->config.hnbap_allow_tmsi) {
-			rc = hnbgw_tx_ue_register_acc_tmsi(ctx, &ies.uE_Identity);
+			rc = hnbgw_tx_ue_register_acc_tmsi(ctx, &ies.uE_Identity, get_next_ue_ctx_id());
 		} else {
 			cause.present = HNBAP_Cause_PR_radioNetwork;
 			cause.choice.radioNetwork = HNBAP_CauseRadioNetwork_invalid_UE_identity;
